You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@trafficserver.apache.org by rr...@apache.org on 2019/04/30 15:31:37 UTC

[trafficserver] branch master updated: Fixes spelling in mgmt

This is an automated email from the ASF dual-hosted git repository.

rrm pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/trafficserver.git


The following commit(s) were added to refs/heads/master by this push:
     new e1bbb95  Fixes spelling in mgmt
e1bbb95 is described below

commit e1bbb9521e805a690dbe1afed7a86c01fdc3377c
Author: Randall Meyer <ra...@yahoo.com>
AuthorDate: Mon Aug 6 21:46:55 2018 -0700

    Fixes spelling in mgmt
---
 mgmt/Alarms.cc                 | 12 ++++++------
 mgmt/Alarms.h                  |  2 +-
 mgmt/DerivativeMetrics.cc      |  4 ++--
 mgmt/FileManager.cc            |  8 ++++----
 mgmt/FileManager.h             |  2 +-
 mgmt/LocalManager.cc           | 14 +++++++-------
 mgmt/MgmtDefs.h                |  2 +-
 mgmt/ProcessManager.cc         |  4 ++--
 mgmt/ProxyConfig.cc            |  2 +-
 mgmt/RecordsConfig.cc          |  4 ++--
 mgmt/Rollback.cc               | 20 ++++++++++----------
 mgmt/Rollback.h                |  4 ++--
 mgmt/WebMgmtUtils.cc           | 30 +++++++++++++++---------------
 mgmt/WebMgmtUtils.h            |  4 ++--
 mgmt/api/CoreAPI.cc            | 12 ++++--------
 mgmt/api/CoreAPIRemote.cc      |  4 ++--
 mgmt/api/CoreAPIShared.cc      |  8 +++-----
 mgmt/api/CoreAPIShared.h       |  2 +-
 mgmt/api/INKMgmtAPI.cc         |  4 ++--
 mgmt/api/NetworkMessage.cc     |  2 +-
 mgmt/api/NetworkMessage.h      |  4 ++--
 mgmt/api/NetworkUtilsRemote.cc |  8 ++++----
 mgmt/api/NetworkUtilsRemote.h  |  3 ++-
 mgmt/api/TSControlMain.cc      |  2 +-
 mgmt/api/include/mgmtapi.h     |  2 +-
 mgmt/utils/MgmtMarshall.cc     |  2 +-
 mgmt/utils/MgmtMarshall.h      |  2 +-
 mgmt/utils/MgmtSocket.cc       |  2 +-
 mgmt/utils/MgmtUtils.cc        |  2 +-
 29 files changed, 83 insertions(+), 88 deletions(-)

diff --git a/mgmt/Alarms.cc b/mgmt/Alarms.cc
index 2240b02..d7a3171 100644
--- a/mgmt/Alarms.cc
+++ b/mgmt/Alarms.cc
@@ -212,7 +212,7 @@ Alarms::signalAlarm(alarm_t a, const char *desc, const char *ip)
   }
 
   /*
-   * Exec alarm bin for priority alarms everytime, regardless if they are
+   * Exec alarm bin for priority alarms every time, regardless if they are
    * potentially duplicates. However, only exec this for you own alarms,
    * don't want every node in the cluster reporting the same alarm.
    */
@@ -223,7 +223,7 @@ Alarms::signalAlarm(alarm_t a, const char *desc, const char *ip)
   ink_mutex_acquire(&mutex);
   if (!ip) {
     // if an OEM alarm, then must create the unique key alarm type;
-    // this key is used to hash the new OEM alarm descritption in the hash table
+    // this key is used to hash the new OEM alarm description in the hash table
     if (a == MGMT_ALARM_ADD_ALARM) {
       a = (alarmOEMcount - minOEMkey) % (maxOEMkey - minOEMkey) + minOEMkey;
       alarmOEMcount++;
@@ -289,7 +289,7 @@ Alarms::signalAlarm(alarm_t a, const char *desc, const char *ip)
     (*(func))(a, ip, desc);
   }
 
-  /* Priority 2 alarms get signalled if they are the first unsolved occurrence. */
+  /* Priority 2 alarms get signaled if they are the first unsolved occurrence. */
   if (priority == 2 && !ip) {
     execAlarmBin(desc);
   }
@@ -318,8 +318,8 @@ Alarms::resetSeenFlag(char *ip)
 
 /*
  * clearUnSeen(...)
- *   This function is a sweeper functionto clean up those alarms that have
- * been taken care of through otehr local managers or at the peer itself.
+ *   This function is a sweeper function to clean up those alarms that have
+ * been taken care of through other local managers or at the peer itself.
  */
 void
 Alarms::clearUnSeen(char *ip)
@@ -350,7 +350,7 @@ void
 Alarms::checkSystemNAlert()
 {
   return;
-} /* End Alarms::checkSystenNAlert */
+} /* End Alarms::checkSystemNAlert */
 
 void
 Alarms::execAlarmBin(const char *desc)
diff --git a/mgmt/Alarms.h b/mgmt/Alarms.h
index 2a0268b..ce3317e 100644
--- a/mgmt/Alarms.h
+++ b/mgmt/Alarms.h
@@ -32,7 +32,7 @@ class AppVersionInfo;
 
 /***********************************************************************
  *
- * MODULARIZATTION: if you are adding new alarms, please ensure to add
+ * MODULARIZATION: if you are adding new alarms, please be sure to add
  *                 the corresponding alarms in lib/records/I_RecAlarms.h
  *
  ***********************************************************************/
diff --git a/mgmt/DerivativeMetrics.cc b/mgmt/DerivativeMetrics.cc
index ca85c8a..16572db 100644
--- a/mgmt/DerivativeMetrics.cc
+++ b/mgmt/DerivativeMetrics.cc
@@ -50,7 +50,7 @@ static const std::vector<DerivativeSum> sum_metrics = {
    RECD_INT,
    {"proxy.process.http.origin_server_response_document_total_size",
     "proxy.process.http.origin_server_response_header_total_size"}},
-  // Total byates of client request and response (total traffic to and from clients)
+  // Total bytes of client request and response (total traffic to and from clients)
   {"proxy.process.user_agent_total_bytes",
    RECD_INT,
    {"proxy.process.http.user_agent_total_request_bytes", "proxy.process.http.user_agent_total_response_bytes"}},
@@ -69,7 +69,7 @@ static const std::vector<DerivativeSum> sum_metrics = {
    RECD_COUNTER,
    {"proxy.process.http.cache_miss_cold", "proxy.process.http.cache_miss_changed", "proxy.process.http.cache_miss_client_no_cache",
     "proxy.process.http.cache_miss_ims", "proxy.process.http.cache_miss_client_not_cacheable"}},
-  // Total requests, both hits and misses (this is slightly superflous, but assures correct percentage calculations)
+  // Total requests, both hits and misses (this is slightly superfluous, but assures correct percentage calculations)
   {"proxy.process.cache_total_requests", RECD_COUNTER, {"proxy.process.cache_total_hits", "proxy.process.cache_total_misses"}},
   // Total cache requests bytes which are cache hits
   {"proxy.process.cache_total_hits_bytes",
diff --git a/mgmt/FileManager.cc b/mgmt/FileManager.cc
index 6e9edfe..9288d92 100644
--- a/mgmt/FileManager.cc
+++ b/mgmt/FileManager.cc
@@ -118,7 +118,7 @@ FileManager::addFileHelper(const char *fileName, const char *configName, bool ro
 //  Sets rbPtr to the rollback object associated
 //    with the passed in fileName.
 //
-//  If there is no binding, falseis returned
+//  If there is no binding, false is returned
 //
 bool
 FileManager::getRollbackObj(const char *fileName, Rollback **rbPtr)
@@ -134,7 +134,7 @@ FileManager::getRollbackObj(const char *fileName, Rollback **rbPtr)
 
 // bool FileManager::fileChanged(const char* fileName)
 //
-//  Called by the Rollback class whenever a a config has changed
+//  Called by the Rollback class whenever a config has changed
 //     Initiates callbacks
 //
 //
@@ -148,7 +148,7 @@ FileManager::fileChanged(const char *fileName, const char *configName, bool incV
 
   for (cb = cblist.head; cb != nullptr; cb = cb->link.next) {
     // Dup the string for each callback to be
-    //  defensive incase it modified when it is not supposed to be
+    //  defensive in case it's modified when it's not supposed to be
     confignameCopy = ats_strdup(configName);
     filenameCopy   = ats_strdup(fileName);
     (*cb->func)(filenameCopy, confignameCopy, incVersion);
@@ -160,7 +160,7 @@ FileManager::fileChanged(const char *fileName, const char *configName, bool incV
 
 // void FileManger::rereadConfig()
 //
-//   Interates through the list of managed files and
+//   Iterates through the list of managed files and
 //     calls Rollback::checkForUserUpdate on them
 //
 //   although it is tempting, DO NOT CALL FROM SIGNAL HANDLERS
diff --git a/mgmt/FileManager.h b/mgmt/FileManager.h
index 94cc7cc..a667504 100644
--- a/mgmt/FileManager.h
+++ b/mgmt/FileManager.h
@@ -62,7 +62,7 @@ enum lockAction_t {
 //       a binding and false otherwise
 //
 //  registerCallback(FileCallbackFunc) - registers a callback function
-//       which will get called everytime a managed file changes.  The
+//       which will get called every time a managed file changes.  The
 //       callback function should NOT use the calling thread to
 //       access any Rollback objects or block for a long time
 //
diff --git a/mgmt/MgmtDefs.h b/mgmt/MgmtDefs.h
index 868ec25..87dadf6 100644
--- a/mgmt/MgmtDefs.h
+++ b/mgmt/MgmtDefs.h
@@ -56,7 +56,7 @@ using MgmtCallback = std::function<void(ts::MemSpan)>;
 //-------------------------------------------------------------------------
 // API conversion functions.
 //-------------------------------------------------------------------------
-/** Conversion functions to and from an aribrary type and Management types.
+/** Conversion functions to and from an arbitrary type and Management types.
  *
  * A type that wants to support conversion in the TS API should create a static instance of this
  * class and fill in the appropriate members. The TS API set/get functions can then check for a
diff --git a/mgmt/ProcessManager.cc b/mgmt/ProcessManager.cc
index abfcb9e..b492c31 100644
--- a/mgmt/ProcessManager.cc
+++ b/mgmt/ProcessManager.cc
@@ -272,10 +272,10 @@ ProcessManager::signalManager(MgmtMessageHdr *mh)
 
 #if HAVE_EVENTFD
   // we don't care about the actual value of wakeup_fd, so just keep adding 1. just need to
-  // wakeup the fd. also, note that wakeup_fd was initalized to non-blocking so we can
+  // wakeup the fd. also, note that wakeup_fd was initialized to non-blocking so we can
   // directly write to it without any timeout checking.
   //
-  // don't tigger if MGMT_EVENT_LIBRECORD because they happen all the time
+  // don't trigger if MGMT_EVENT_LIBRECORD because they happen all the time
   // and don't require a quick response. for MGMT_EVENT_LIBRECORD, rely on timeouts so
   // traffic_server can spend more time doing other things/
   uint64_t one = 1;
diff --git a/mgmt/ProxyConfig.cc b/mgmt/ProxyConfig.cc
index 9c189ca..67199ee 100644
--- a/mgmt/ProxyConfig.cc
+++ b/mgmt/ProxyConfig.cc
@@ -145,7 +145,7 @@ ConfigProcessor::set(unsigned int id, ConfigInfo *info, unsigned timeout_secs)
 
   if (old_info) {
     // The ConfigInfoReleaser now takes our refcount, but
-    // someother thread might also have one ...
+    // some other thread might also have one ...
     ink_assert(old_info->refcount() > 0);
     eventProcessor.schedule_in(new ConfigInfoReleaser(id, old_info), HRTIME_SECONDS(timeout_secs));
   }
diff --git a/mgmt/RecordsConfig.cc b/mgmt/RecordsConfig.cc
index 8e8b5a0..b382acc 100644
--- a/mgmt/RecordsConfig.cc
+++ b/mgmt/RecordsConfig.cc
@@ -1189,7 +1189,7 @@ static const RecordElement RecordsConfig[] =
 
   //##############################################################################
   //#
-  //# Congifuration for TLSv1.3 and above
+  //# Configuration for TLSv1.3 and above
   //#
   //##############################################################################
   // The default value (nullptr) means the default value of TLS stack will be used.
@@ -1219,7 +1219,7 @@ static const RecordElement RecordsConfig[] =
   ,
 
   // Interim configuration setting for obeying keepalive requests on internal
-  // (PLuginVC) sessions. See TS-4960 and friends.
+  // (PluginVC) sessions. See TS-4960 and friends.
   {RECT_LOCAL, "proxy.config.http.keepalive_internal_vc", RECD_INT, "0", RECU_DYNAMIC, RR_NULL, RECC_INT, "[0-1]", RECA_NULL},
 
   //##############################################################################
diff --git a/mgmt/Rollback.cc b/mgmt/Rollback.cc
index 05e4c42..0f4af40 100644
--- a/mgmt/Rollback.cc
+++ b/mgmt/Rollback.cc
@@ -63,7 +63,7 @@ Rollback::Rollback(const char *fileName_, const char *configName_, bool root_acc
     numberBackups(0)
 {
   version_t highestSeen;             // the highest backup version
-  ExpandingArray existVer(25, true); // Exsisting versions
+  ExpandingArray existVer(25, true); // Existing versions
   struct stat fileInfo;
   MgmtInt numBak;
   char *alarmMsg;
@@ -123,7 +123,7 @@ Rollback::Rollback(const char *fileName_, const char *configName_, bool root_acc
   //
   if (statFile(ACTIVE_VERSION, &fileInfo) < 0) {
     // If we can't find an active version because there is not
-    //   one, attempt to rollback to a previous verision if one exists
+    //   one, attempt to rollback to a previous version if one exists
     //
     // If it does not, create a zero length file to prevent total havoc
     //
@@ -143,7 +143,7 @@ Rollback::Rollback(const char *fileName_, const char *configName_, bool root_acc
           needZeroLength = false;
           highestSeen--;
           // Since we've made the highestVersion active
-          //  remove it from the backup verision q
+          //  remove it from the backup version q
           versionQ.remove(versionQ.tail);
         }
         ats_free(highestSeenStr);
@@ -383,7 +383,7 @@ Rollback::internalUpdate(TextBuffer *buf, version_t newVersion, bool notifyChang
 
   // Check to see if the callee has specified a newVersion number
   //   If the newVersion argument is less than zero, the callee
-  //   is telling us to use the next version in squence
+  //   is telling us to use the next version in sequence
   if (newVersion < 0) {
     newVersion = this->currentVersion + 1;
     if (incVersion) {
@@ -469,7 +469,7 @@ Rollback::internalUpdate(TextBuffer *buf, version_t newVersion, bool notifyChang
     newBak->modTime = 0;
     versionQ.enqueue(newBak);
   }
-  // Update instance varibles
+  // Update instance variables
   this->numVersions++;
   this->currentVersion = newVersion;
 
@@ -731,7 +731,7 @@ Rollback::extractVersionInfo(ExpandingArray *listNames, const char *testFileName
 //   Add wrapper to
 //     version_t Rollback::findVersions_ml(ExpandingArray* listNames)
 //
-//   Puts the data in a queue rather than an ExpaningArray
+//   Puts the data in a queue rather than an ExpandingArray
 //
 version_t
 Rollback::findVersions_ml(Queue<versionInfo> &q)
@@ -860,7 +860,7 @@ Rollback::setLastModifiedTime()
     fileLastModified = TS_ARCHIVE_STAT_MTIME(fileInfo);
     return true;
   } else {
-    // We really shoudn't fail to stat the file since we just
+    // We really shouldn't fail to stat the file since we just
     //  created it.  If we do, just punt and just use the current
     //  time.
     fileLastModified = (time(nullptr) - ink_timezone()) * 1000000000;
@@ -872,14 +872,14 @@ Rollback::setLastModifiedTime()
 //
 //  Called to check if the file has been changed
 //    by the user.  Timestamps are compared to see if a
-//    change occured
+//    change occurred
 //
 //  If the file has been changed, a new version is rolled.
-//    The new current version and its predicessor will
+//    The new current version and its predecessor will
 //    be the same in this case.  While this is pointless,
 //    for Rolling backward, we need to the version number
 //    to up'ed so that WebFileEdit knows that the file has
-//    changed.  Rolling a new verion also has the effect
+//    changed.  Rolling a new version also has the effect
 //    of creating a new timestamp
 //
 bool
diff --git a/mgmt/Rollback.h b/mgmt/Rollback.h
index 2ea74e4..bdcaebd 100644
--- a/mgmt/Rollback.h
+++ b/mgmt/Rollback.h
@@ -94,7 +94,7 @@ struct versionInfo {
 //
 //  checkForUserUpdate() - compares the last known modification time
 //    of the active version of the file with that files current modification
-//    time.  Returns true if the file has been chaged manually or false
+//    time.  Returns true if the file has been changed manually or false
 //    if it hasn't
 //
 //  versionTimeStamp(version_t) - returns the modification time (mtime)
@@ -250,6 +250,6 @@ private:
   Queue<versionInfo> versionQ; // stores the backup version info
 };
 
-// qSort comptable function to sort versionInfo*
+// qSort compatible function to sort versionInfo*
 //   based on version number
 int versionCmp(const void *i1, const void *i2);
diff --git a/mgmt/WebMgmtUtils.cc b/mgmt/WebMgmtUtils.cc
index fa7fd9e..81b17e0 100644
--- a/mgmt/WebMgmtUtils.cc
+++ b/mgmt/WebMgmtUtils.cc
@@ -100,11 +100,11 @@ varSetFromStr(const char *varName, const char *value)
 
 // bool varSetFloat(const char* varName, RecFloat value)
 //
-//  Sets the variable specifed by varName to value.  varName
+//  Sets the variable specified by varName to value.  varName
 //   must be a RecFloat variable.  No conversion is done for
 //   other types unless convert is set to ture. In the case
 //   of convert is ture, type conversion is perform if applicable.
-//   By default, convert is set to be false and can be overrided
+//   By default, convert is set to be false and can be overridden
 //   when the function is called.
 //
 bool
@@ -151,11 +151,11 @@ varSetFloat(const char *varName, RecFloat value, bool convert)
 
 // bool varSetCounter(const char* varName, RecCounter value)
 //
-//  Sets the variable specifed by varName to value.  varName
+//  Sets the variable specified by varName to value.  varName
 //   must be an RecCounter variable.  No conversion is done for
 //   other types unless convert is set to ture. In the case
 //   of convert is ture, type conversion is perform if applicable.
-//   By default, convert is set to be false and can be overrided
+//   By default, convert is set to be false and can be overridden
 //   when the function is called.
 //
 bool
@@ -201,11 +201,11 @@ varSetCounter(const char *varName, RecCounter value, bool convert)
 
 // bool varSetInt(const char* varName, RecInt value)
 //
-//  Sets the variable specifed by varName to value.  varName
+//  Sets the variable specified by varName to value.  varName
 //   must be an RecInt variable.  No conversion is done for
 //   other types unless convert is set to ture. In the case
 //   of convert is ture, type conversion is perform if applicable.
-//   By default, convert is set to be false and can be overrided
+//   By default, convert is set to be false and can be overridden
 //   when the function is called.
 //
 bool
@@ -251,7 +251,7 @@ varSetInt(const char *varName, RecInt value, bool convert)
 
 // bool varSetData(RecDataT varType, const char *varName, RecData value)
 //
-//  Sets the variable specifed by varName to value. value and varName
+//  Sets the variable specified by varName to value. value and varName
 //   must be varType variables.
 //
 bool
@@ -279,7 +279,7 @@ varSetData(RecDataT varType, const char *varName, RecData value)
 //
 //   Sets the *value to value of the varName according varType.
 //
-//  return true if bufVal was succefully set
+//  return true if bufVal was successfully set
 //    and false otherwise
 //
 bool
@@ -296,7 +296,7 @@ varDataFromName(RecDataT varType, const char *varName, RecData *value)
 //
 //   Sets the *value to value of the varName.
 //
-//  return true if bufVal was succefully set
+//  return true if bufVal was successfully set
 //    and false otherwise
 //
 bool
@@ -345,7 +345,7 @@ varCounterFromName(const char *varName, RecCounter *value)
 //
 //   Sets the *value to value of the varName.
 //
-//  return true if bufVal was succefully set
+//  return true if bufVal was successfully set
 //    and false otherwise
 //
 bool
@@ -395,7 +395,7 @@ varFloatFromName(const char *varName, RecFloat *value)
 //
 //   Sets the *value to value of the varName.
 //
-//  return true if bufVal was succefully set
+//  return true if bufVal was successfully set
 //    and false otherwise
 //
 bool
@@ -548,12 +548,12 @@ bytesFromInt(RecInt bytes, char *bufVal)
 //   Sets the bufVal string to the value of the local manager
 //     named by varName.  bufLen is size of bufVal
 //
-//  return true if bufVal was succefully set
+//  return true if bufVal was successfully set
 //    and false otherwise
 //
 //  EVIL ALERT: overviewRecord::varStrFromName is extremely
 //    similar to this function except in how it gets it's
-//    data.  Changes to this fuction must be propogated
+//    data.  Changes to this function must be propagated
 //    to its twin.  Cut and Paste sucks but there is not
 //    an easy way to merge the functions
 //
@@ -933,7 +933,7 @@ setHostnameVar()
   return 0;
 }
 
-// void appendDefautDomain(char* hostname, int bufLength)
+// void appendDefaultDomain(char* hostname, int bufLength)
 //
 //   Appends the pasted in hostname with the default
 //     domain if the hostname is an unqualified name
@@ -949,7 +949,7 @@ appendDefaultDomain(char *hostname, int bufLength)
 {
   int len                 = strlen(hostname);
   const char msg[]        = "Nodes will be know by their unqualified host name";
-  static int error_before = 0; // Race ok since effect is multple error msg
+  static int error_before = 0; // Race ok since effect is multiple error msg
 
   ink_assert(len < bufLength);
   ink_assert(bufLength >= 64);
diff --git a/mgmt/WebMgmtUtils.h b/mgmt/WebMgmtUtils.h
index 9112785..26cb01d 100644
--- a/mgmt/WebMgmtUtils.h
+++ b/mgmt/WebMgmtUtils.h
@@ -62,9 +62,9 @@ bool varFloatFromName(const char *varName, RecFloat *value);
 bool varCounterFromName(const char *varName, RecCounter *value);
 bool varDataFromName(RecDataT varType, const char *varName, RecData *value);
 
-// No conversion done.  varName must represnt a value of the appropriate
+// No conversion done.  varName must represent a value of the appropriate
 //  type
-// Default arguement "convert" added to allow great flexiblity in type checking
+// Default argument "convert" added to allow great flexibility in type checking
 bool varSetInt(const char *varName, RecInt value, bool convert = false);
 bool varSetCounter(const char *varName, RecCounter value, bool convert = false);
 bool varSetFloat(const char *varName, RecFloat value, bool convert = false);
diff --git a/mgmt/api/CoreAPI.cc b/mgmt/api/CoreAPI.cc
index 56da4d4..4959513 100644
--- a/mgmt/api/CoreAPI.cc
+++ b/mgmt/api/CoreAPI.cc
@@ -57,7 +57,7 @@ extern FileManager *configFiles; // global in traffic_manager
 /*-------------------------------------------------------------------------
  * Init
  *-------------------------------------------------------------------------
- * performs any necesary initializations for the local API client,
+ * performs any necessary initializations for the local API client,
  * eg. set up global structures; called by the TSMgmtAPI::TSInit()
  */
 TSMgmtError
@@ -79,7 +79,7 @@ Init(const char * /* socket_path ATS_UNUSED */, TSInitOptionT options)
 /*-------------------------------------------------------------------------
  * Terminate
  *-------------------------------------------------------------------------
- * performs any necesary cleanup of global structures, etc,
+ * performs any necessary cleanup of global structures, etc,
  * for the local API client,
  */
 TSMgmtError
@@ -112,7 +112,7 @@ ProxyShutdown()
 
   lmgmt->processShutdown(false /* only shut down the proxy*/);
 
-  // Wait for awhile for shtudown to happen
+  // Wait for awhile for shutdown to happen
   do {
     mgmt_sleep_sec(1);
     i++;
@@ -559,7 +559,7 @@ MgmtRecordGet(const char *rec_name, TSRecordEle *rec_ele)
     Debug("RecOp", "[MgmtRecordGet] Get String Var %s = %s", rec_ele->rec_name, rec_ele->valueT.string_val);
     break;
 
-  default: // UNKOWN TYPE
+  default: // UNKNOWN TYPE
     Debug("RecOp", "[MgmtRecordGet] Get Failed : %d is Unknown Var type %s", rec_type, rec_name);
     return TS_ERR_FAIL;
   }
@@ -917,7 +917,3 @@ StatsReset(const char *name)
   lmgmt->clearStats(name);
   return TS_ERR_OKAY;
 }
-
-/*-------------------------------------------------------------
- * rmserver.cfg
- *-------------------------------------------------------------*/
diff --git a/mgmt/api/CoreAPIRemote.cc b/mgmt/api/CoreAPIRemote.cc
index 8406d78..fbcdc42 100644
--- a/mgmt/api/CoreAPIRemote.cc
+++ b/mgmt/api/CoreAPIRemote.cc
@@ -263,7 +263,7 @@ Terminate()
 
   // cancel the listening socket thread
   // it's important to call this before setting paths to NULL because the
-  // socket_test_thread actually will try to reconnect() and this funntion
+  // socket_test_thread actually will try to reconnect() and this function
   // will seg fault if the socket paths are NULL while it is connecting;
   // the thread will be cancelled at a cancellation point in the
   // socket_test_thread, eg. sleep
@@ -484,7 +484,7 @@ StorageDeviceCmdOffline(const char *dev)
 }
 
 /*-------------------------------------------------------------------------
- * LIfecycle Alert
+ * Lifecycle Alert
  *-------------------------------------------------------------------------
  * Send alert to plugins
  */
diff --git a/mgmt/api/CoreAPIShared.cc b/mgmt/api/CoreAPIShared.cc
index 8446258..5ee8fd8 100644
--- a/mgmt/api/CoreAPIShared.cc
+++ b/mgmt/api/CoreAPIShared.cc
@@ -77,7 +77,7 @@ END:
 }
 
 /* readHTTPResponse
- * - read from an openned socket to memory-allocated buffer and close the
+ * - read from an opened socket to memory-allocated buffer and close the
  *   socket regardless success or failure.
  * INPUT:  sock -- the socket to read the response from
  *         buffer -- the buffer to be filled with the HTTP response
@@ -132,7 +132,7 @@ error: /* "Houston, we have a problem!" (Apollo 13) */
 }
 
 /* sendHTTPRequest
- * - Compose a HTTP GET request and sent it via an openned socket.
+ * - Compose a HTTP GET request and sent it via an opened socket.
  * INPUT:  sock -- the socket to send the message to
  *         req  -- the request to send
  * OUTPUT: bool -- true if everything went well. false otherwise (and sock is
@@ -182,7 +182,6 @@ error: /* "Houston, we have a problem!" (Apollo 13) */
   return TS_ERR_NET_WRITE;
 }
 
-/* Modified from TrafficCop.cc (open_socket) */
 int
 connectDirect(const char *host, int port, uint64_t /* timeout ATS_UNUSED */)
 {
@@ -241,7 +240,6 @@ error:
   return -1;
 } /* connectDirect */
 
-/* COPIED direclty form TrafficCop.cc */
 static int
 poll_read(int fd, int timeout)
 {
@@ -336,7 +334,7 @@ get_event_id(const char *event_name)
 /**********************************************************************
  * get_event_id
  *
- * Purpose: based on alarm_id, determine the corresonding alarm name
+ * Purpose: based on alarm_id, determine the corresponding alarm name
  * Note:    allocates memory for the name returned
  *********************************************************************/
 char *
diff --git a/mgmt/api/CoreAPIShared.h b/mgmt/api/CoreAPIShared.h
index c5b6c0d..eaa8682 100644
--- a/mgmt/api/CoreAPIShared.h
+++ b/mgmt/api/CoreAPIShared.h
@@ -65,7 +65,7 @@
 
 // used by TSReadFromUrl
 #define HTTP_DIVIDER "\r\n\r\n"
-#define URL_BUFSIZE 65536 // the max. lenght of URL obtainable (in bytes)
+#define URL_BUFSIZE 65536 // the max. length of URL obtainable (in bytes)
 #define URL_TIMEOUT 5000  // the timeout value for send/recv HTTP in ms
 #define HTTP_PORT 80
 #define BUFSIZE 1024
diff --git a/mgmt/api/INKMgmtAPI.cc b/mgmt/api/INKMgmtAPI.cc
index e332764..7b0626c 100644
--- a/mgmt/api/INKMgmtAPI.cc
+++ b/mgmt/api/INKMgmtAPI.cc
@@ -512,7 +512,7 @@ END:
  *-------------------------------------------------------------------------
  * Purpose: Retrieves list of record values specified in the rec_names list
  * Input: rec_names - list of record names to retrieve
- *        rec_vals  - queue of TSRecordEle* that correspons to rec_names
+ *        rec_vals  - queue of TSRecordEle* that corresponds to rec_names
  * Output: If at any point, while retrieving one of the records there's a
  *         a failure then the entire process is aborted, all the allocated
  *         TSRecordEle's are deallocated and TS_ERR_FAIL is returned.
@@ -658,7 +658,7 @@ TSRecordSetMlt(TSList rec_list, TSActionNeedT *action_need)
       }
 
       // keep track of most severe action; reset if needed
-      // the TSACtionNeedT should be listed such that most severe actions have
+      // the TSActionNeedT should be listed such that most severe actions have
       // a lower number (so most severe action == 0)
       if (*action_need < top_action_req) { // a more severe action
         top_action_req = *action_need;
diff --git a/mgmt/api/NetworkMessage.cc b/mgmt/api/NetworkMessage.cc
index de2e7fa..a9ba89b 100644
--- a/mgmt/api/NetworkMessage.cc
+++ b/mgmt/api/NetworkMessage.cc
@@ -36,7 +36,7 @@ struct NetCmdOperation {
   const MgmtMarshallType fields[MAX_OPERATION_FIELDS];
 };
 
-// Requests always begin with a OpType, followed by aditional fields.
+// Requests always begin with a OpType, followed by additional fields.
 static const struct NetCmdOperation requests[] = {
   /* RECORD_SET                 */ {3, {MGMT_MARSHALL_INT, MGMT_MARSHALL_STRING, MGMT_MARSHALL_STRING}},
   /* RECORD_GET                 */ {2, {MGMT_MARSHALL_INT, MGMT_MARSHALL_STRING}},
diff --git a/mgmt/api/NetworkMessage.h b/mgmt/api/NetworkMessage.h
index 99c979b..70f15e7 100644
--- a/mgmt/api/NetworkMessage.h
+++ b/mgmt/api/NetworkMessage.h
@@ -28,7 +28,7 @@
 #define REMOTE_DELIM ':'
 #define REMOTE_DELIM_STR ":"
 
-#define MAX_CONN_TRIES 10 // maximum number of attemps to reconnect to TM
+#define MAX_CONN_TRIES 10 // maximum number of attempts to reconnect to TM
 
 // the possible operations or msg types sent from remote client to TM
 enum class OpType : MgmtMarshallInt {
@@ -75,7 +75,7 @@ struct mgmt_message_sender {
 TSMgmtError send_mgmt_request(const mgmt_message_sender &snd, OpType optype, ...);
 TSMgmtError send_mgmt_request(int fd, OpType optype, ...);
 
-// Marshall and send an error respose for this operation type.
+// Marshall and send an error response for this operation type.
 TSMgmtError send_mgmt_error(int fd, OpType op, TSMgmtError error);
 
 // Parse a request message from a buffer.
diff --git a/mgmt/api/NetworkUtilsRemote.cc b/mgmt/api/NetworkUtilsRemote.cc
index 35e731b..e5c4984 100644
--- a/mgmt/api/NetworkUtilsRemote.cc
+++ b/mgmt/api/NetworkUtilsRemote.cc
@@ -96,7 +96,7 @@ socket_test(int fd)
  *          requests & issues out responses and alerts
  * 1) create and set the client socket_fd; connect to TM
  * 2) create and set the client's event_socket_fd; connect to TM
- * output: TS_ERR_OKAY          - if both sockets sucessfully connect to TM
+ * output: TS_ERR_OKAY          - if both sockets successfully connect to TM
  *         TS_ERR_NET_ESTABLISH - at least one unsuccessful connection
  * notes: If connection breaks it is responsibility of client to reconnect
  *        otherwise traffic server will assume mgmt stopped request and
@@ -209,11 +209,11 @@ disconnect()
 /***************************************************************************
  * reconnect
  *
- * purpose: reconnects to TM (eg. when TM restarts); does all the necesarry
+ * purpose: reconnects to TM (eg. when TM restarts); does all the necessary
  *          set up for reconnection
  * input: None
  * output: TS_ERR_FAIL, TS_ERR_OKAY
- * notes: necessarry events for a new client-TM connection:
+ * notes: necessary events for a new client-TM connection:
  * 1) get new socket_fd using old socket_path by calling connect()
  * 2) relaunch event_poll_thread_main with new socket_fd
  * 3) re-notify TM of all the client's registered callbacks by send msg
@@ -239,7 +239,7 @@ reconnect()
   // relaunch a new event thread since socket_fd changed
   if (0 == (ts_init_options & TS_MGMT_OPT_NO_EVENTS)) {
     ink_thread_create(&ts_event_thread, event_poll_thread_main, &event_socket_fd, 0, 0, nullptr);
-    // reregister the callbacks on the TM side for this new client connection
+    // re-register the callbacks on the TM side for this new client connection
     if (remote_event_callbacks) {
       err = send_register_all_callbacks(event_socket_fd, remote_event_callbacks);
       if (err != TS_ERR_OKAY) { // problem establishing connection
diff --git a/mgmt/api/NetworkUtilsRemote.h b/mgmt/api/NetworkUtilsRemote.h
index 30f1a48..f8413dd 100644
--- a/mgmt/api/NetworkUtilsRemote.h
+++ b/mgmt/api/NetworkUtilsRemote.h
@@ -56,7 +56,8 @@ void set_socket_paths(const char *path);
  * the client connection information stored in the variables in
  * NetworkUtilsRemote.cc
  */
-TSMgmtError ts_connect(); /* TODO: update documenation, Renamed due to conflict with connect() in <sys/socket.h> on some platforms*/
+TSMgmtError
+ts_connect(); /* TODO: update documentation, Renamed due to conflict with connect() in <sys/socket.h> on some platforms*/
 TSMgmtError disconnect();
 TSMgmtError reconnect();
 TSMgmtError reconnect_loop(int num_attempts);
diff --git a/mgmt/api/TSControlMain.cc b/mgmt/api/TSControlMain.cc
index 57a6761..b9f49a1 100644
--- a/mgmt/api/TSControlMain.cc
+++ b/mgmt/api/TSControlMain.cc
@@ -828,7 +828,7 @@ handle_host_status_down(int fd, void *req, size_t reqlen)
 /**************************************************************************
  * handle_api_ping
  *
- * purpose: handles the API_PING messaghat is sent by API clients to keep
+ * purpose: handles the API_PING message that is sent by API clients to keep
  *    the management socket alive
  * output: TS_ERR_xx. There is no response message.
  *************************************************************************/
diff --git a/mgmt/api/include/mgmtapi.h b/mgmt/api/include/mgmtapi.h
index 588592b..c88c0df 100644
--- a/mgmt/api/include/mgmtapi.h
+++ b/mgmt/api/include/mgmtapi.h
@@ -432,7 +432,7 @@ tsapi TSMgmtError TSHostStatusSetUp(const char *host_name, int down_time, const
 tsapi TSMgmtError TSHostStatusSetDown(const char *host_name, int down_time, const char *reason);
 /*--- statistics operations -----------------------------------------------*/
 /* TSStatsReset: sets all the statistics variables to their default values
- * Outpue: TSErrr
+ * Output: TSMgmtError
  */
 tsapi TSMgmtError TSStatsReset(const char *name);
 
diff --git a/mgmt/utils/MgmtMarshall.cc b/mgmt/utils/MgmtMarshall.cc
index 35263c3..5152da9 100644
--- a/mgmt/utils/MgmtMarshall.cc
+++ b/mgmt/utils/MgmtMarshall.cc
@@ -1,6 +1,6 @@
 /** @file
 
-  Managment packet marshalling.
+  Management packet marshalling.
 
   @section license License
 
diff --git a/mgmt/utils/MgmtMarshall.h b/mgmt/utils/MgmtMarshall.h
index 11c3d92..91bc257 100644
--- a/mgmt/utils/MgmtMarshall.h
+++ b/mgmt/utils/MgmtMarshall.h
@@ -1,6 +1,6 @@
 /** @file
 
-  Managment packet marshalling.
+  Management packet marshalling.
 
   @section license License
 
diff --git a/mgmt/utils/MgmtSocket.cc b/mgmt/utils/MgmtSocket.cc
index 5bd6bb0..2ad3fc6 100644
--- a/mgmt/utils/MgmtSocket.cc
+++ b/mgmt/utils/MgmtSocket.cc
@@ -183,7 +183,7 @@ mgmt_select(int nfds, fd_set *readfds, fd_set *writefds, fd_set *errorfds, struc
 // Note: Linux select() has slight different semantics.  From the
 // man page: "On Linux, timeout is modified to reflect the amount of
 // time not slept; most other implementations do not do this."
-// Linux select() can also return ENOMEM, so we espeically need to
+// Linux select() can also return ENOMEM, so we especially need to
 // protect the call with the transient error retry loop.
 // Fortunately, because of the Linux timeout handling, our
 // mgmt_select call will still timeout correctly, rather than
diff --git a/mgmt/utils/MgmtUtils.cc b/mgmt/utils/MgmtUtils.cc
index 71e5fd6..3ac6642 100644
--- a/mgmt/utils/MgmtUtils.cc
+++ b/mgmt/utils/MgmtUtils.cc
@@ -334,7 +334,7 @@ mgmt_getAddrForIntr(char *intrName, sockaddr *addr, int *mtu)
   int fakeSocket;            // a temporary socket to pass to ioctl
   struct ifconf ifc;         // ifconf information
   char *ifbuf;               // ifconf buffer
-  struct ifreq *ifr, *ifend; // pointer to individual inferface info
+  struct ifreq *ifr, *ifend; // pointer to individual interface info
   int lastlen;
   int len;
diff --git a/mgmt/LocalManager.cc b/mgmt/LocalManager.cc
index fae81d3..15ec02e 100644
--- a/mgmt/LocalManager.cc
+++ b/mgmt/LocalManager.cc
@@ -151,8 +151,8 @@ LocalManager::clearStats(const char *name)
   //  before the proxy clears them, but this should be rare.
   //
   //  Doing things in the opposite order prevents that race
-  //   but excerbates the race between the node and cluster
-  //   stats getting cleared by progation of clearing the
+  //   but exacerbates the race between the node and cluster
+  //   stats getting cleared by propagation of clearing the
   //   cluster stats
   //
   if (name && *name) {
@@ -756,10 +756,10 @@ LocalManager::signalEvent(int msg_id, const char *data_raw, int data_len)
 
 #if HAVE_EVENTFD
   // we don't care about the actual value of wakeup_fd, so just keep adding 1. just need to
-  // wakeup the fd. also, note that wakeup_fd was initalized to non-blocking so we can
+  // wakeup the fd. also, note that wakeup_fd was initialized to non-blocking so we can
   // directly write to it without any timeout checking.
   //
-  // don't tigger if MGMT_EVENT_LIBRECORD because they happen all the time
+  // don't trigger if MGMT_EVENT_LIBRECORD because they happen all the time
   // and don't require a quick response. for MGMT_EVENT_LIBRECORD, rely on timeouts so
   // traffic_server can spend more time doing other things
   uint64_t one = 1;
@@ -834,7 +834,7 @@ LocalManager::startProxy(const char *onetime_options)
   pid_t pid;
 
   // Before we do anything lets check for the existence of
   // the traffic server binary along with it's execute permmissions
   if (access(absolute_proxy_binary, F_OK) < 0) {
     // Error can't find traffic_server
     mgmt_elog(errno, "[LocalManager::startProxy] Unable to find traffic server at %s\n", absolute_proxy_binary);
@@ -843,7 +843,7 @@ LocalManager::startProxy(const char *onetime_options)
   // traffic server binary exists, check permissions
   else if (access(absolute_proxy_binary, R_OK | X_OK) < 0) {
     // Error don't have proper permissions
-    mgmt_elog(errno, "[LocalManager::startProxy] Unable to access %s due to bad permisssions \n", absolute_proxy_binary);
+    mgmt_elog(errno, "[LocalManager::startProxy] Unable to access %s due to bad permissions \n", absolute_proxy_binary);
     return false;
   }
 
@@ -981,7 +981,7 @@ LocalManager::listenForProxy()
       this->bindProxyPort(p);
     }
 
-    // read backlong configuration value and overwrite the default value if found
+    // read backlog configuration value and overwrite the default value if found
     bool found;
     std::string_view fam{ats_ip_family_name(p.m_family)};
     RecInt backlog = REC_readInteger("proxy.config.net.listen_backlog", &found);
@@ -834,7 +834,7 @@ LocalManager::startProxy(const char *onetime_options)
 
   // Before we do anything lets check for the existence of
-  // the traffic server binary along with it's execute permmissions
+  // the traffic server binary along with it's execute permissions
   if (access(absolute_proxy_binary, F_OK) < 0) {
     // Error can't find traffic_server